@@ -4,11 +4,11 @@ use std::ops::{Add, Div, Mul, Rem, Sub};
 
 use arrow::array::PrimitiveArray;
 use arrow::compute::arithmetics::basic;
-#[cfg(feature = "dtype-i128")]
+#[cfg(feature = "dtype-decimal")]
 use arrow::compute::arithmetics::decimal;
 use arrow::compute::arity_assign;
 use arrow::types::NativeType;
-use num::{Num, NumCast, ToPrimitive};
+use num_traits::{Num, NumCast, ToPrimitive};
 
 use crate::prelude::*;
 use crate::series::IsSorted;
@@ -61,7 +61,7 @@ macro_rules! native_array_arithmetics {
 
 native_array_arithmetics!(u8, u16, u32, u64, i8, i16, i32, i64, f32, f64);
 
-#[cfg(feature = "dtype-i128")]
+#[cfg(feature = "dtype-decimal")]
 impl ArrayArithmetics for i128 {
     fn add(lhs: &PrimitiveArray<Self>, rhs: &PrimitiveArray<Self>) -> PrimitiveArray<Self> {
         decimal::add(lhs, rhs)
@@ -540,7 +540,6 @@ fn concat_strings(l: &str, r: &str) -> String {
     s
 }
 
-#[cfg(feature = "dtype-binary")]
 fn concat_binary_arrs(l: &[u8], r: &[u8]) -> Vec<u8> {
     let mut v = Vec::with_capacity(l.len() + r.len());
     v.extend_from_slice(l);
@@ -610,7 +609,6 @@ impl Add<&str> for &Utf8Chunked {
     }
 }
 
-#[cfg(feature = "dtype-binary")]
 impl Add for &BinaryChunked {
     type Output = BinaryChunked;
 
@@ -646,7 +644,6 @@ impl Add for &BinaryChunked {
     }
 }
 
-#[cfg(feature = "dtype-binary")]
 impl Add for BinaryChunked {
     type Output = BinaryChunked;
 
@@ -655,7 +652,6 @@ impl Add for BinaryChunked {
     }
 }
 
-#[cfg(feature = "dtype-binary")]
 impl Add<&[u8]> for &BinaryChunked {
     type Output = BinaryChunked;
 
