@@ -587,34 +587,10 @@ mod test {
         let ca = Float32Chunked::from_slice(
             "",
             &[
-                0.166189,
-                0.166559,
-                0.168517,
-                0.169393,
-                0.175272,
-                0.23316699999999999,
-                0.238787,
-                0.266562,
-                0.26903,
-                0.285792,
-                0.292801,
-                0.29342899999999994,
-                0.30170600000000003,
-                0.308534,
-                0.331489,
-                0.346095,
-                0.36764399999999997,
-                0.36993899999999996,
-                0.37207399999999996,
-                0.41014000000000006,
-                0.415789,
-                0.421781,
-                0.4277250000000001,
-                0.46536299999999997,
-                0.500208,
-                2.6217269999999995,
-                2.803311,
-                3.868526,
+                0.166189, 0.166559, 0.168517, 0.169393, 0.175272, 0.233167, 0.238787, 0.266562,
+                0.26903, 0.285792, 0.292801, 0.293429, 0.301706, 0.308534, 0.331489, 0.346095,
+                0.367644, 0.369939, 0.372074, 0.41014, 0.415789, 0.421781, 0.427725, 0.465363,
+                0.500208, 2.621727, 2.803311, 3.868526,
             ],
         );
         assert!((ca.median().unwrap() - 0.3200115).abs() < 0.0001)
@@ -895,34 +871,10 @@ mod test {
         let ca = Float32Chunked::from_slice(
             "",
             &[
-                0.166189,
-                0.166559,
-                0.168517,
-                0.169393,
-                0.175272,
-                0.23316699999999999,
-                0.238787,
-                0.266562,
-                0.26903,
-                0.285792,
-                0.292801,
-                0.29342899999999994,
-                0.30170600000000003,
-                0.308534,
-                0.331489,
-                0.346095,
-                0.36764399999999997,
-                0.36993899999999996,
-                0.37207399999999996,
-                0.41014000000000006,
-                0.415789,
-                0.421781,
-                0.4277250000000001,
-                0.46536299999999997,
-                0.500208,
-                2.6217269999999995,
-                2.803311,
-                3.868526,
+                0.166189, 0.166559, 0.168517, 0.169393, 0.175272, 0.233167, 0.238787, 0.266562,
+                0.26903, 0.285792, 0.292801, 0.293429, 0.301706, 0.308534, 0.331489, 0.346095,
+                0.367644, 0.369939, 0.372074, 0.41014, 0.415789, 0.421781, 0.427725, 0.465363,
+                0.500208, 2.621727, 2.803311, 3.868526,
             ],
         );
 
