@@ -18,15 +18,16 @@ where
 
         // Safety:
         // Length of iter is trusted
-        ListChunked::from_chunks(
-            self.name(),
-            vec![Box::new(unsafe {
-                LargeListArray::from_iter_primitive_trusted_len::<T::Native, _, _>(
-                    iter,
-                    T::get_dtype().to_arrow(),
-                )
-            })],
-        )
+        unsafe {
+            ListChunked::from_chunks(
+                self.name(),
+                vec![Box::new(LargeListArray::from_iter_primitive_trusted_len::<
+                    T::Native,
+                    _,
+                    _,
+                >(iter, T::get_dtype().to_arrow()))],
+            )
+        }
     }
 }
 impl RepeatBy for BooleanChunked {
@@ -38,16 +39,17 @@ impl RepeatBy for BooleanChunked {
 
         // Safety:
         // Length of iter is trusted
-        ListChunked::from_chunks(
-            self.name(),
-            vec![Box::new(unsafe {
-                LargeListArray::from_iter_bool_trusted_len(iter)
-            })],
-        )
+        unsafe {
+            ListChunked::from_chunks(
+                self.name(),
+                vec![Box::new(LargeListArray::from_iter_bool_trusted_len(iter))],
+            )
+        }
     }
 }
 impl RepeatBy for Utf8Chunked {
     fn repeat_by(&self, by: &IdxCa) -> ListChunked {
+        // TODO! dispatch via binary.
         let iter = self
             .into_iter()
             .zip(by.into_iter())
@@ -55,15 +57,17 @@ impl RepeatBy for Utf8Chunked {
 
         // Safety:
         // Length of iter is trusted
-        ListChunked::from_chunks(
-            self.name(),
-            vec![Box::new(unsafe {
-                LargeListArray::from_iter_utf8_trusted_len(iter, self.len())
-            })],
-        )
+        unsafe {
+            ListChunked::from_chunks(
+                self.name(),
+                vec![Box::new(LargeListArray::from_iter_utf8_trusted_len(
+                    iter,
+                    self.len(),
+                ))],
+            )
+        }
     }
 }
-#[cfg(feature = "dtype-binary")]
 impl RepeatBy for BinaryChunked {
     fn repeat_by(&self, by: &IdxCa) -> ListChunked {
         let iter = self
@@ -73,11 +77,14 @@ impl RepeatBy for BinaryChunked {
 
         // Safety:
         // Length of iter is trusted
-        ListChunked::from_chunks(
-            self.name(),
-            vec![Box::new(unsafe {
-                LargeListArray::from_iter_binary_trusted_len(iter, self.len())
-            })],
-        )
+        unsafe {
+            ListChunked::from_chunks(
+                self.name(),
+                vec![Box::new(LargeListArray::from_iter_binary_trusted_len(
+                    iter,
+                    self.len(),
+                ))],
+            )
+        }
     }
 }
