@@ -22,6 +22,9 @@ mod proxy;
 pub use into_groups::*;
 pub use proxy::*;
 
+#[cfg(feature = "dtype-struct")]
+use crate::prelude::sort::arg_sort_multiple::encode_rows_vertical;
+
 // This will remove the sorted flag on signed integers
 fn prepare_dataframe_unsorted(by: &[Series]) -> DataFrame {
     DataFrame::new_no_checks(
@@ -75,6 +78,14 @@ impl DataFrame {
             let series = &by[0];
             series.group_tuples(multithreaded, sorted)
         } else {
+            #[cfg(feature = "dtype-struct")]
+            {
+                if by.iter().any(|s| matches!(s.dtype(), DataType::Struct(_))) {
+                    let rows = encode_rows_vertical(&by)?;
+                    let groups = rows.group_tuples(multithreaded, sorted)?;
+                    return Ok(GroupBy::new(self, by, groups, None));
+                }
+            }
             let keys_df = prepare_dataframe_unsorted(&by);
             groupby_threaded_multiple_keys_flat(keys_df, n_partitions, sorted)
         };
@@ -899,7 +910,7 @@ pub fn fmt_groupby_column(name: &str, method: GroupByMethod) -> String {
 mod test {
     use num_traits::FloatConst;
 
-    use crate::frame::groupby::{groupby, groupby_threaded_num};
+    use crate::frame::groupby::groupby;
     use crate::prelude::*;
     use crate::utils::split_ca;
 
@@ -932,7 +943,7 @@ mod test {
         // Select multiple
         let out = df
             .groupby_stable(["date"])?
-            .select(&["temp", "rain"])
+            .select(["temp", "rain"])
             .mean()?;
         assert_eq!(
             out.column("temp_mean")?,
@@ -943,7 +954,7 @@ mod test {
         #[allow(deprecated)]
         // Group by multiple
         let out = df
-            .groupby_stable(&["date", "temp"])?
+            .groupby_stable(["date", "temp"])?
             .select(["rain"])
             .mean()?;
         assert!(out.column("rain_mean").is_ok());
@@ -989,7 +1000,7 @@ mod test {
         // Use of deprecated `sum()` for testing purposes
         #[allow(deprecated)]
         let adf = df
-            .groupby(&[
+            .groupby([
                 "G1", "G2", "G3", "G4", "G5", "G6", "G7", "G8", "G9", "G10", "G11", "G12",
             ])
             .unwrap()
@@ -1034,7 +1045,7 @@ mod test {
         #[allow(deprecated)]
         // Compute the aggregated DataFrame by the 13 columns defined in `series_names`.
         let adf = df
-            .groupby(&series_names)
+            .groupby(series_names)
             .unwrap()
             .select(["N"])
             .sum()
@@ -1102,26 +1113,6 @@ mod test {
         );
     }
 
-    #[test]
-    #[cfg_attr(miri, ignore)]
-    fn test_groupby_threaded() {
-        for slice in &[
-            vec![1, 2, 3, 4, 4, 4, 2, 1],
-            vec![1, 2, 3, 4, 4, 4, 2, 1, 1],
-            vec![1, 2, 3, 4, 4, 4],
-        ] {
-            let ca = UInt32Chunked::new("", slice);
-            let split = split_ca(&ca, 4).unwrap();
-
-            let a = groupby(ca.into_iter(), true).into_idx();
-
-            let keys = split.iter().map(|ca| ca.cont_slice().unwrap()).collect();
-            let b = groupby_threaded_num(keys, 0, split.len() as u64, true).into_idx();
-
-            assert_eq!(a, b);
-        }
-    }
-
     #[test]
     #[cfg_attr(miri, ignore)]
     fn test_groupby_null_handling() -> PolarsResult<()> {
