@@ -37,7 +37,7 @@ impl Series {
         let offsets = vec![0i64, values.len() as i64];
         let inner_type = self.dtype();
 
-        let data_type = ListArray::<i64>::default_datatype(inner_type.to_physical().to_arrow());
+        let data_type = ListArray::<i64>::default_datatype(values.data_type().clone());
 
         // Safety:
         // offsets are correct;
@@ -52,9 +52,7 @@ impl Series {
         let name = self.name();
 
         let mut ca = unsafe { ListChunked::from_chunks(name, vec![Box::new(arr)]) };
-        if self.dtype() != &self.dtype().to_physical() {
-            ca.to_logical(inner_type.clone())
-        }
+        ca.to_logical(inner_type.clone());
         ca.set_fast_explode();
 
         Ok(ca)
