@@ -1,6 +1,7 @@
 use std::any::Any;
 
 use polars_core::prelude::*;
+use polars_plan::dsl::Expr;
 
 use crate::operators::DataChunk;
 
@@ -10,4 +11,6 @@ pub trait PhysicalPipedExpr: Send + Sync {
     fn evaluate(&self, chunk: &DataChunk, lazy_state: &dyn Any) -> PolarsResult<Series>;
 
     fn field(&self, input_schema: &Schema) -> PolarsResult<Field>;
+
+    fn expression(&self) -> Expr;
 }
