@@ -10,6 +10,7 @@ from polars.convert import (
     from_numpy,
     from_pandas,
     from_records,
+    from_repr,
 )
 from polars.dataframe import DataFrame
 from polars.datatypes import (
@@ -53,7 +54,7 @@ from polars.exceptions import (
     DuplicateError,
     InvalidOperationError,
     NoDataError,
-    PanicException,
+    PolarsPanicError,
     SchemaError,
     SchemaFieldNotFoundError,
     ShapeError,
@@ -76,7 +77,6 @@ from polars.functions.lazy import (
     arange,
     arg_sort_by,
     arg_where,
-    argsort_by,
     avg,
     coalesce,
     col,
@@ -147,7 +147,12 @@ from polars.io import (
 from polars.lazyframe import LazyFrame
 from polars.series import Series
 from polars.sql import SQLContext
-from polars.string_cache import StringCache, toggle_string_cache, using_string_cache
+from polars.string_cache import (
+    StringCache,
+    enable_string_cache,
+    toggle_string_cache,
+    using_string_cache,
+)
 from polars.type_aliases import PolarsDataType
 from polars.utils import (
     build_info,
@@ -174,7 +179,7 @@ __all__ = [
     "DuplicateError",
     "InvalidOperationError",
     "NoDataError",
-    "PanicException",
+    "PolarsPanicError",
     "SchemaError",
     "SchemaFieldNotFoundError",
     "ShapeError",
@@ -243,6 +248,7 @@ __all__ = [
     "scan_pyarrow_dataset",
     # polars.stringcache
     "StringCache",
+    "enable_string_cache",
     "toggle_string_cache",
     "using_string_cache",
     # polars.config
@@ -266,7 +272,6 @@ __all__ = [
     "apply",
     "arange",
     "arg_sort_by",
-    "argsort_by",
     "avg",
     "coalesce",
     "col",
@@ -316,6 +321,7 @@ __all__ = [
     "from_numpy",
     "from_pandas",
     "from_records",
+    "from_repr",
     # polars.sql
     "SQLContext",
     # polars.utils
