@@ -15,8 +15,7 @@ from polars.dependencies import _PYARROW_AVAILABLE
 from polars.dependencies import pandas as pd
 from polars.dependencies import pyarrow as pa
 from polars.exceptions import NoDataError
-from polars.utils.decorators import deprecate_nonkeyword_arguments, deprecated_alias
-from polars.utils.various import _cast_repr_strings_with_schema
+from polars.utils.various import _cast_repr_strings_with_schema, parse_version
 
 if TYPE_CHECKING:
     from polars.dataframe import DataFrame
@@ -25,7 +24,6 @@ if TYPE_CHECKING:
     from polars.type_aliases import Orientation, SchemaDefinition, SchemaDict
 
 
-@deprecated_alias(columns="schema")
 def from_dict(
     data: Mapping[str, Sequence[object] | Mapping[str, Sequence[object]] | Series],
     schema: SchemaDefinition | None = None,
@@ -80,14 +78,12 @@ def from_dict(
     )
 
 
-@deprecate_nonkeyword_arguments(allowed_args=["data", "schema"])
-@deprecated_alias(dicts="data", stacklevel=4)
 def from_dicts(
     data: Sequence[dict[str, Any]],
-    infer_schema_length: int | None = N_INFER_DEFAULT,
-    *,
     schema: SchemaDefinition | None = None,
+    *,
     schema_overrides: SchemaDict | None = None,
+    infer_schema_length: int | None = N_INFER_DEFAULT,
 ) -> DataFrame:
     """
     Construct a DataFrame from a sequence of dictionaries. This operation clones data.
@@ -96,9 +92,6 @@ def from_dicts(
     ----------
     data
         Sequence with dictionaries mapping column name to value
-    infer_schema_length
-        How many dictionaries/rows to scan to determine the data types
-        if set to `None` then ALL dicts are scanned; this will be slow.
     schema : Sequence of str, (str,DataType) pairs, or a {str:DataType,} dict
         The DataFrame schema may be declared in several ways:
 
@@ -117,6 +110,9 @@ def from_dicts(
         them to the schema.
     schema_overrides : dict, default None
         Support override of inferred types for one or more columns.
+    infer_schema_length
+        How many dictionaries/rows to scan to determine the data types
+        if set to `None` then ALL dicts are scanned; this will be slow.
 
     Returns
     -------
@@ -184,7 +180,6 @@ def from_dicts(
     )
 
 
-@deprecated_alias(columns="schema")
 def from_records(
     data: Sequence[Sequence[Any]],
     schema: SchemaDefinition | None = None,
@@ -367,7 +362,6 @@ def from_repr(tbl: str) -> DataFrame:
     return _cast_repr_strings_with_schema(df, schema)
 
 
-@deprecated_alias(columns="schema")
 def from_numpy(
     data: np.ndarray[Any, Any],
     schema: SchemaDefinition | None = None,
@@ -429,12 +423,23 @@ def from_numpy(
     )
 
 
-@deprecate_nonkeyword_arguments(allowed_args=["data", "schema"])
+# Note: we cannot @overload the typing (Series vs DataFrame) here, as pyarrow
+# does not implement any support for type hints; attempts to hint here will
+# simply result in mypy inferring "Any", which isn't useful...
+
+
 def from_arrow(
-    data: pa.Table | pa.Array | pa.ChunkedArray,
-    rechunk: bool = True,
+    data: (
+        pa.Table
+        | pa.Array
+        | pa.ChunkedArray
+        | pa.RecordBatch
+        | Sequence[pa.RecordBatch]
+    ),
     schema: SchemaDefinition | None = None,
+    *,
     schema_overrides: SchemaDict | None = None,
+    rechunk: bool = True,
 ) -> DataFrame | Series:
     """
     Create a DataFrame or Series from an Arrow Table or Array.
@@ -444,10 +449,8 @@ def from_arrow(
 
     Parameters
     ----------
-    data : :class:`pyarrow.Table` or :class:`pyarrow.Array`
-        Data representing an Arrow Table or Array.
-    rechunk : bool, default True
-        Make sure that all data is in contiguous memory.
+    data : :class:`pyarrow.Table`, :class:`pyarrow.Array`, one or more :class:`pyarrow.RecordBatch`
+        Data representing an Arrow Table, Array, or sequence of RecordBatches.
     schema : Sequence of str, (str,DataType) pairs, or a {str:DataType,} dict
         The DataFrame schema may be declared in several ways:
 
@@ -461,6 +464,8 @@ def from_arrow(
     schema_overrides : dict, default None
         Support type specification or override of one or more columns; note that
         any dtypes inferred from the schema param will be overridden.
+    rechunk : bool, default True
+        Make sure that all data is in contiguous memory.
 
     Returns
     -------
@@ -489,34 +494,56 @@ def from_arrow(
 
     >>> import pyarrow as pa
     >>> data = pa.array([1, 2, 3])
-    >>> series = pl.from_arrow(data)
+    >>> series = pl.from_arrow(data, schema={"s": pl.Int32})
     >>> series
     shape: (3,)
-    Series: '' [i64]
+    Series: 's' [i32]
     [
         1
         2
         3
     ]
 
-    """
+    """  # noqa: W505
     if isinstance(data, pa.Table):
         return pli.DataFrame._from_arrow(
-            data, rechunk=rechunk, schema=schema, schema_overrides=schema_overrides
+            data=data, rechunk=rechunk, schema=schema, schema_overrides=schema_overrides
         )
     elif isinstance(data, (pa.Array, pa.ChunkedArray)):
-        return pli.Series._from_arrow("", data, rechunk)
+        name = getattr(data, "_name", "") or ""
+        s = pli.DataFrame(
+            data=pli.Series._from_arrow(name, data, rechunk=rechunk),
+            schema=schema,
+            schema_overrides=schema_overrides,
+        ).to_series()
+        return (
+            s if (name or schema or schema_overrides) else s.rename("", in_place=True)
+        )
+
+    if isinstance(data, pa.RecordBatch):
+        data = [data]
+    if isinstance(data, Sequence) and data and isinstance(data[0], pa.RecordBatch):
+        return pli.DataFrame._from_arrow(
+            data=pa.Table.from_batches(data),
+            rechunk=rechunk,
+            schema=schema,
+            schema_overrides=schema_overrides,
+        )
+    elif isinstance(data, Sequence) and (schema or schema_overrides) and not data:
+        return pli.DataFrame(data=[], schema=schema, schema_overrides=schema_overrides)
     else:
-        raise ValueError(f"expected Arrow Table or Array, got {type(data)}.")
+        raise ValueError(
+            f"expected pyarrow Table, Array, or sequence of RecordBatches; got {type(data)}."
+        )
 
 
 @overload
 def from_pandas(
     data: pd.DataFrame,
+    *,
+    schema_overrides: SchemaDict | None = ...,
     rechunk: bool = ...,
     nan_to_null: bool = ...,
-    schema_overrides: SchemaDict | None = ...,
-    *,
     include_index: bool = ...,
 ) -> DataFrame:
     ...
@@ -525,23 +552,21 @@ def from_pandas(
 @overload
 def from_pandas(
     data: pd.Series | pd.DatetimeIndex,
+    *,
+    schema_overrides: SchemaDict | None = ...,
     rechunk: bool = ...,
     nan_to_null: bool = ...,
-    schema_overrides: SchemaDict | None = ...,
-    *,
     include_index: bool = ...,
 ) -> Series:
     ...
 
 
-@deprecate_nonkeyword_arguments()
-@deprecated_alias(nan_to_none="nan_to_null", df="data", stacklevel=4)
 def from_pandas(
     data: pd.DataFrame | pd.Series | pd.DatetimeIndex,
+    *,
+    schema_overrides: SchemaDict | None = None,
     rechunk: bool = True,
     nan_to_null: bool = True,
-    schema_overrides: SchemaDict | None = None,
-    *,
     include_index: bool = False,
 ) -> DataFrame | Series:
     """
@@ -555,12 +580,12 @@ def from_pandas(
     ----------
     data: :class:`pandas.DataFrame`, :class:`pandas.Series`, :class:`pandas.DatetimeIndex`
         Data represented as a pandas DataFrame, Series, or DatetimeIndex.
+    schema_overrides : dict, default None
+        Support override of inferred types for one or more columns.
     rechunk : bool, default True
         Make sure that all data is in contiguous memory.
     nan_to_null : bool, default True
         If data contains `NaN` values PyArrow will convert the ``NaN`` to ``None``
-    schema_overrides : dict, default None
-        Support override of inferred types for one or more columns.
     include_index : bool, default False
         Load any non-default pandas indexes as columns.
 
@@ -615,8 +640,7 @@ def from_pandas(
         raise ValueError(f"Expected pandas DataFrame or Series, got {type(data)}.")
 
 
-@deprecate_nonkeyword_arguments()
-def from_dataframe(df: Any, allow_copy: bool = True) -> DataFrame:
+def from_dataframe(df: Any, *, allow_copy: bool = True) -> DataFrame:
     """
     Build a Polars DataFrame from any dataframe supporting the interchange protocol.
 
@@ -648,7 +672,7 @@ def from_dataframe(df: Any, allow_copy: bool = True) -> DataFrame:
             f"`df` of type {type(df)} does not support the dataframe interchange"
             " protocol."
         )
-    if not _PYARROW_AVAILABLE or int(pa.__version__.split(".")[0]) < 11:
+    if not _PYARROW_AVAILABLE or parse_version(pa.__version__) < parse_version("11"):
         raise ImportError(
             "pyarrow>=11.0.0 is required for converting a dataframe interchange object"
             " to a Polars dataframe."
