@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import warnings
 from typing import TYPE_CHECKING
 
 from polars.datatypes import (
@@ -10,12 +11,14 @@ from polars.datatypes import (
     is_polars_dtype,
     py_type_to_dtype,
 )
+from polars.utils import no_default
 from polars.utils._parse_expr_input import expr_to_lit_or_expr
 from polars.utils._wrap import wrap_expr
 
 if TYPE_CHECKING:
     from polars.expr.expr import Expr
     from polars.type_aliases import PolarsDataType, PolarsTemporalType, TransferEncoding
+    from polars.utils import NoDefault
 
 
 class ExprStringNameSpace:
@@ -30,10 +33,11 @@ class ExprStringNameSpace:
         self,
         datatype: PolarsTemporalType,
         fmt: str | None = None,
+        *,
         strict: bool = True,
         exact: bool = True,
         cache: bool = True,
-        tz_aware: bool = False,
+        tz_aware: bool | NoDefault = no_default,
         utc: bool = False,
     ) -> Expr:
         """
@@ -56,7 +60,11 @@ class ExprStringNameSpace:
             Use a cache of unique, converted dates to apply the datetime conversion.
         tz_aware
             Parse timezone aware datetimes. This may be automatically toggled by the
-            'fmt' given.
+            `fmt` given.
+
+            .. deprecated:: 0.16.17
+                This is now auto-inferred from the given `fmt`. You can safely drop
+                this argument, it will be removed in a future version.
         utc
             Parse timezone aware datetimes as UTC. This may be useful if you have data
             with mixed offsets.
@@ -114,11 +122,21 @@ class ExprStringNameSpace:
         if not is_polars_dtype(datatype):  # pragma: no cover
             raise ValueError(f"expected: {DataType} got: {datatype}")
 
+        if tz_aware is no_default:
+            tz_aware = False
+        else:
+            warnings.warn(
+                "`tz_aware` is now auto-inferred from `fmt` and will be removed "
+                "in a future version. You can safely drop this argument.",
+                category=DeprecationWarning,
+                stacklevel=2,
+            )
+
         if datatype == Date:
             return wrap_expr(self._pyexpr.str_parse_date(fmt, strict, exact, cache))
         elif datatype == Datetime:
-            tu = datatype.tu  # type: ignore[union-attr]
-            tz = datatype.tz  # type: ignore[union-attr]
+            time_unit = datatype.time_unit  # type: ignore[union-attr]
+            time_zone = datatype.time_zone  # type: ignore[union-attr]
             dtcol = wrap_expr(
                 self._pyexpr.str_parse_datetime(
                     fmt,
@@ -127,11 +145,11 @@ class ExprStringNameSpace:
                     cache,
                     tz_aware,
                     utc,
-                    tu,
-                    tz,
+                    time_unit,
+                    time_zone,
                 )
             )
-            return dtcol if (tu is None) else dtcol.dt.cast_time_unit(tu)
+            return dtcol if (time_unit is None) else dtcol.dt.cast_time_unit(time_unit)
         elif datatype == Time:
             return wrap_expr(self._pyexpr.str_parse_time(fmt, strict, exact, cache))
         else:  # pragma: no cover
@@ -274,13 +292,13 @@ class ExprStringNameSpace:
         """
         return wrap_expr(self._pyexpr.str_to_lowercase())
 
-    def strip(self, matches: str | None = None) -> Expr:
+    def strip(self, characters: str | None = None) -> Expr:
         r"""
         Remove leading and trailing characters.
 
         Parameters
         ----------
-        matches
+        characters
             The set of characters to be removed. All combinations of this set of
             characters will be stripped. If set to None (default), all whitespace is
             removed instead.
@@ -314,15 +332,15 @@ class ExprStringNameSpace:
         └─────────┘
 
         """
-        return wrap_expr(self._pyexpr.str_strip(matches))
+        return wrap_expr(self._pyexpr.str_strip(characters))
 
-    def lstrip(self, matches: str | None = None) -> Expr:
+    def lstrip(self, characters: str | None = None) -> Expr:
         r"""
         Remove leading characters.
 
         Parameters
         ----------
-        matches
+        characters
             The set of characters to be removed. All combinations of this set of
             characters will be stripped. If set to None (default), all whitespace is
             removed instead.
@@ -356,15 +374,15 @@ class ExprStringNameSpace:
         └─────────┘
 
         """
-        return wrap_expr(self._pyexpr.str_lstrip(matches))
+        return wrap_expr(self._pyexpr.str_lstrip(characters))
 
-    def rstrip(self, matches: str | None = None) -> Expr:
+    def rstrip(self, characters: str | None = None) -> Expr:
         r"""
         Remove trailing characters.
 
         Parameters
         ----------
-        matches
+        characters
             The set of characters to be removed. All combinations of this set of
             characters will be stripped. If set to None (default), all whitespace is
             removed instead.
@@ -398,7 +416,7 @@ class ExprStringNameSpace:
         └─────────┘
 
         """
-        return wrap_expr(self._pyexpr.str_rstrip(matches))
+        return wrap_expr(self._pyexpr.str_rstrip(characters))
 
     def zfill(self, alignment: int) -> Expr:
         """
@@ -444,11 +462,11 @@ class ExprStringNameSpace:
         """
         return wrap_expr(self._pyexpr.str_zfill(alignment))
 
-    def ljust(self, width: int, fillchar: str = " ") -> Expr:
+    def ljust(self, width: int, fill_char: str = " ") -> Expr:
         """
         Return the string left justified in a string of length ``width``.
 
-        Padding is done using the specified ``fillchar``.
+        Padding is done using the specified ``fill_char``.
         The original string is returned if ``width`` is less than or equal to
         ``len(s)``.
 
@@ -456,7 +474,7 @@ class ExprStringNameSpace:
         ----------
         width
             Justify left to this length.
-        fillchar
+        fill_char
             Fill with this ASCII character.
 
         Examples
@@ -476,13 +494,13 @@ class ExprStringNameSpace:
         └──────────────┘
 
         """
-        return wrap_expr(self._pyexpr.str_ljust(width, fillchar))
+        return wrap_expr(self._pyexpr.str_ljust(width, fill_char))
 
-    def rjust(self, width: int, fillchar: str = " ") -> Expr:
+    def rjust(self, width: int, fill_char: str = " ") -> Expr:
         """
         Return the string right justified in a string of length ``width``.
 
-        Padding is done using the specified ``fillchar``.
+        Padding is done using the specified ``fill_char``.
         The original string is returned if ``width`` is less than or equal to
         ``len(s)``.
 
@@ -490,7 +508,7 @@ class ExprStringNameSpace:
         ----------
         width
             Justify right to this length.
-        fillchar
+        fill_char
             Fill with this ASCII character.
 
         Examples
@@ -510,10 +528,10 @@ class ExprStringNameSpace:
         └──────────────┘
 
         """
-        return wrap_expr(self._pyexpr.str_rjust(width, fillchar))
+        return wrap_expr(self._pyexpr.str_rjust(width, fill_char))
 
     def contains(
-        self, pattern: str | Expr, literal: bool = False, strict: bool = True
+        self, pattern: str | Expr, *, literal: bool = False, strict: bool = True
     ) -> Expr:
         """
         Check if string contains a substring that matches a regex.
@@ -521,7 +539,8 @@ class ExprStringNameSpace:
         Parameters
         ----------
         pattern
-            A valid regex pattern.
+            A regex pattern compatible with the `regex crate
+            <https://docs.rs/regex/latest/regex/>`_.
         literal
             Treat pattern as a literal string.
         strict
@@ -559,13 +578,13 @@ class ExprStringNameSpace:
         pattern = expr_to_lit_or_expr(pattern, str_to_lit=True)._pyexpr
         return wrap_expr(self._pyexpr.str_contains(pattern, literal, strict))
 
-    def ends_with(self, sub: str | Expr) -> Expr:
+    def ends_with(self, suffix: str | Expr) -> Expr:
         """
         Check if string values end with a substring.
 
         Parameters
         ----------
-        sub
+        suffix
             Suffix substring.
 
         Examples
@@ -603,16 +622,16 @@ class ExprStringNameSpace:
         starts_with : Check if string values start with a substring.
 
         """
-        sub = expr_to_lit_or_expr(sub, str_to_lit=True)._pyexpr
-        return wrap_expr(self._pyexpr.str_ends_with(sub))
+        suffix = expr_to_lit_or_expr(suffix, str_to_lit=True)._pyexpr
+        return wrap_expr(self._pyexpr.str_ends_with(suffix))
 
-    def starts_with(self, sub: str | Expr) -> Expr:
+    def starts_with(self, prefix: str | Expr) -> Expr:
         """
         Check if string values start with a substring.
 
         Parameters
         ----------
-        sub
+        prefix
             Prefix substring.
 
         Examples
@@ -650,8 +669,8 @@ class ExprStringNameSpace:
         ends_with : Check if string values end with a substring.
 
         """
-        sub = expr_to_lit_or_expr(sub, str_to_lit=True)._pyexpr
-        return wrap_expr(self._pyexpr.str_starts_with(sub))
+        prefix = expr_to_lit_or_expr(prefix, str_to_lit=True)._pyexpr
+        return wrap_expr(self._pyexpr.str_starts_with(prefix))
 
     def json_extract(self, dtype: PolarsDataType | None = None) -> Expr:
         """
@@ -802,7 +821,8 @@ class ExprStringNameSpace:
         Parameters
         ----------
         pattern
-            A valid regex pattern
+            A regex pattern compatible with the `regex crate
+            <https://docs.rs/regex/latest/regex/>`_.
         group_index
             Index of the targeted capture group.
             Group 0 mean the whole pattern, first group begin at index 1
@@ -852,7 +872,8 @@ class ExprStringNameSpace:
         Parameters
         ----------
         pattern
-            A valid regex pattern
+            A regex pattern compatible with the `regex crate
+            <https://docs.rs/regex/latest/regex/>`_.
 
         Returns
         -------
@@ -888,7 +909,8 @@ class ExprStringNameSpace:
         Parameters
         ----------
         pattern
-            A valid regex pattern
+            A regex pattern compatible with the `regex crate
+            <https://docs.rs/regex/latest/regex/>`_.
 
         Returns
         -------
@@ -915,7 +937,7 @@ class ExprStringNameSpace:
         """
         return wrap_expr(self._pyexpr.count_match(pattern))
 
-    def split(self, by: str, inclusive: bool = False) -> Expr:
+    def split(self, by: str, *, inclusive: bool = False) -> Expr:
         """
         Split the string by a substring.
 
@@ -950,7 +972,7 @@ class ExprStringNameSpace:
             return wrap_expr(self._pyexpr.str_split_inclusive(by))
         return wrap_expr(self._pyexpr.str_split(by))
 
-    def split_exact(self, by: str, n: int, inclusive: bool = False) -> Expr:
+    def split_exact(self, by: str, n: int, *, inclusive: bool = False) -> Expr:
         """
         Split the string by a substring using ``n`` splits.
 
@@ -1085,8 +1107,8 @@ class ExprStringNameSpace:
         self,
         pattern: str | Expr,
         value: str | Expr,
-        literal: bool = False,
         *,
+        literal: bool = False,
         n: int = 1,
     ) -> Expr:
         r"""
@@ -1095,7 +1117,8 @@ class ExprStringNameSpace:
         Parameters
         ----------
         pattern
-            Regex pattern.
+            A regex pattern compatible with the `regex crate
+            <https://docs.rs/regex/latest/regex/>`_.
         value
             Replacement string.
         literal
@@ -1131,7 +1154,7 @@ class ExprStringNameSpace:
         )
 
     def replace_all(
-        self, pattern: str | Expr, value: str | Expr, literal: bool = False
+        self, pattern: str | Expr, value: str | Expr, *, literal: bool = False
     ) -> Expr:
         """
         Replace all matching regex/literal substrings with a new string value.
@@ -1139,7 +1162,8 @@ class ExprStringNameSpace:
         Parameters
         ----------
         pattern
-            Regex pattern.
+            A regex pattern compatible with the `regex crate
+            <https://docs.rs/regex/latest/regex/>`_.
         value
             Replacement string.
         literal
@@ -1254,7 +1278,7 @@ class ExprStringNameSpace:
         """
         return wrap_expr(self._pyexpr.explode())
 
-    def parse_int(self, radix: int = 2, strict: bool = True) -> Expr:
+    def parse_int(self, radix: int = 2, *, strict: bool = True) -> Expr:
         """
         Parse integers with base radix from strings.
 
@@ -1267,7 +1291,7 @@ class ExprStringNameSpace:
             Default: 2.
 
         strict
-            Bool, Defult=True will raise any ParseError or overflow as ComputeError.
+            Bool, Default=True will raise any ParseError or overflow as ComputeError.
             False silently convert to Null.
 
         Returns
@@ -1277,7 +1301,7 @@ class ExprStringNameSpace:
         Examples
         --------
         >>> df = pl.DataFrame({"bin": ["110", "101", "010", "invalid"]})
-        >>> df.select(pl.col("bin").str.parse_int(2, False))
+        >>> df.select(pl.col("bin").str.parse_int(2, strict=False))
         shape: (4, 1)
         ┌──────┐
         │ bin  │
@@ -1291,7 +1315,7 @@ class ExprStringNameSpace:
         └──────┘
 
         >>> df = pl.DataFrame({"hex": ["fa1e", "ff00", "cafe", None]})
-        >>> df.select(pl.col("hex").str.parse_int(16, True))
+        >>> df.select(pl.col("hex").str.parse_int(16, strict=True))
         shape: (4, 1)
         ┌───────┐
         │ hex   │
