@@ -250,8 +250,13 @@ impl PyExpr {
     }
 
     #[cfg(feature = "top_k")]
-    pub fn top_k(&self, k: usize, descending: bool) -> PyExpr {
-        self.inner.clone().top_k(k, descending).into()
+    pub fn top_k(&self, k: usize) -> PyExpr {
+        self.inner.clone().top_k(k).into()
+    }
+
+    #[cfg(feature = "top_k")]
+    pub fn bottom_k(&self, k: usize) -> PyExpr {
+        self.inner.clone().bottom_k(k).into()
     }
 
     pub fn arg_max(&self) -> PyExpr {
@@ -564,7 +569,7 @@ impl PyExpr {
             .into()
     }
 
-    #[pyo3(signature = (fmt, strict, exact, cache, tz_aware, utc, tu, tz))]
+    #[pyo3(signature = (fmt, strict, exact, cache, tz_aware, utc, time_unit, time_zone))]
     #[allow(clippy::too_many_arguments)]
     pub fn str_parse_datetime(
         &self,
@@ -574,11 +579,11 @@ impl PyExpr {
         cache: bool,
         tz_aware: bool,
         utc: bool,
-        tu: Option<Wrap<TimeUnit>>,
-        tz: Option<TimeZone>,
+        time_unit: Option<Wrap<TimeUnit>>,
+        time_zone: Option<TimeZone>,
     ) -> PyExpr {
-        let result_tu = match (&fmt, tu) {
-            (_, Some(tu)) => tu.0,
+        let result_time_unit = match (&fmt, time_unit) {
+            (_, Some(time_unit)) => time_unit.0,
             (Some(fmt), None) => {
                 if fmt.contains("%.9f")
                     || fmt.contains("%9f")
@@ -598,7 +603,7 @@ impl PyExpr {
             .clone()
             .str()
             .strptime(StrpTimeOptions {
-                date_dtype: DataType::Datetime(result_tu, tz),
+                date_dtype: DataType::Datetime(result_time_unit, time_zone),
                 fmt,
                 strict,
                 exact,
@@ -809,7 +814,7 @@ impl PyExpr {
             .inner
             .map(
                 move |s| s.binary().map(|s| Some(s.hex_encode().into_series())),
-                GetOutput::same_type(),
+                GetOutput::from_type(DataType::Utf8),
             )
             .with_fmt("binary.hex_encode")
             .into()
@@ -836,7 +841,7 @@ impl PyExpr {
             .inner
             .map(
                 move |s| s.binary().map(|s| Some(s.base64_encode().into_series())),
-                GetOutput::same_type(),
+                GetOutput::from_type(DataType::Utf8),
             )
             .with_fmt("binary.base64_encode")
             .into()
@@ -1056,8 +1061,8 @@ impl PyExpr {
             )
             .into()
     }
-    pub fn timestamp(&self, tu: Wrap<TimeUnit>) -> PyExpr {
-        self.inner.clone().dt().timestamp(tu.0).into()
+    pub fn timestamp(&self, time_unit: Wrap<TimeUnit>) -> PyExpr {
+        self.inner.clone().dt().timestamp(time_unit.0).into()
     }
 
     pub fn dt_offset_by(&self, by: &str) -> PyExpr {
@@ -1078,28 +1083,28 @@ impl PyExpr {
             .into()
     }
 
-    pub fn dt_with_time_unit(&self, tu: Wrap<TimeUnit>) -> PyExpr {
-        self.inner.clone().dt().with_time_unit(tu.0).into()
+    pub fn dt_with_time_unit(&self, time_unit: Wrap<TimeUnit>) -> PyExpr {
+        self.inner.clone().dt().with_time_unit(time_unit.0).into()
     }
 
     #[cfg(feature = "timezones")]
-    pub fn dt_convert_time_zone(&self, tz: TimeZone) -> PyExpr {
-        self.inner.clone().dt().convert_time_zone(tz).into()
+    pub fn dt_convert_time_zone(&self, time_zone: TimeZone) -> PyExpr {
+        self.inner.clone().dt().convert_time_zone(time_zone).into()
     }
 
-    pub fn dt_cast_time_unit(&self, tu: Wrap<TimeUnit>) -> PyExpr {
-        self.inner.clone().dt().cast_time_unit(tu.0).into()
+    pub fn dt_cast_time_unit(&self, time_unit: Wrap<TimeUnit>) -> PyExpr {
+        self.inner.clone().dt().cast_time_unit(time_unit.0).into()
     }
 
     #[cfg(feature = "timezones")]
-    pub fn dt_replace_time_zone(&self, tz: Option<String>) -> PyExpr {
-        self.inner.clone().dt().replace_time_zone(tz).into()
+    pub fn dt_replace_time_zone(&self, time_zone: Option<String>) -> PyExpr {
+        self.inner.clone().dt().replace_time_zone(time_zone).into()
     }
 
     #[cfg(feature = "timezones")]
     #[allow(deprecated)]
-    pub fn dt_tz_localize(&self, tz: String) -> PyExpr {
-        self.inner.clone().dt().tz_localize(tz).into()
+    pub fn dt_tz_localize(&self, time_zone: String) -> PyExpr {
+        self.inner.clone().dt().tz_localize(time_zone).into()
     }
 
     pub fn dt_truncate(&self, every: &str, offset: &str) -> PyExpr {
@@ -1110,8 +1115,12 @@ impl PyExpr {
         self.inner.clone().dt().round(every, offset).into()
     }
 
-    pub fn dt_combine(&self, time: PyExpr, tu: Wrap<TimeUnit>) -> PyExpr {
-        self.inner.clone().dt().combine(time.inner, tu.0).into()
+    pub fn dt_combine(&self, time: PyExpr, time_unit: Wrap<TimeUnit>) -> PyExpr {
+        self.inner
+            .clone()
+            .dt()
+            .combine(time.inner, time_unit.0)
+            .into()
     }
 
     #[pyo3(signature = (lambda, window_size, weights, min_periods, center))]
@@ -1628,12 +1637,12 @@ impl PyExpr {
             .into())
     }
 
-    fn rank(&self, method: Wrap<RankMethod>, descending: bool) -> Self {
+    fn rank(&self, method: Wrap<RankMethod>, descending: bool, seed: Option<u64>) -> Self {
         let options = RankOptions {
             method: method.0,
             descending,
         };
-        self.inner.clone().rank(options).into()
+        self.inner.clone().rank(options, seed).into()
     }
 
     fn diff(&self, n: usize, null_behavior: Wrap<NullBehavior>) -> Self {
