@@ -84,7 +84,7 @@ def test_min_max_2850() -> None:
     maximum = 130352833.0
 
     for _ in range(10):
-        permuted = df.sample(frac=1.0, seed=0)
+        permuted = df.sample(fraction=1.0, seed=0)
         computed = permuted.select(
             [pl.col("id").min().alias("min"), pl.col("id").max().alias("max")]
         )
