@@ -75,3 +75,20 @@ def test_empty_sort() -> None:
 def test_object_to_dicts() -> None:
     df = pl.DataFrame({"d": [{"a": 1, "b": 2, "c": 3}]}, schema={"d": pl.Object})
     assert df.to_dicts() == [{"d": {"a": 1, "b": 2, "c": 3}}]
+
+
+def test_object_concat() -> None:
+    df1 = pl.DataFrame(
+        {"a": [1, 2, 3]},
+        schema={"a": pl.Object},
+    )
+
+    df2 = pl.DataFrame(
+        {"a": [1, 4, 3]},
+        schema={"a": pl.Object},
+    )
+
+    catted = pl.concat([df1, df2])
+    assert catted.shape == (6, 1)
+    assert catted.dtypes == [pl.Object]
+    assert catted.to_dict(False) == {"a": [1, 2, 3, 1, 4, 3]}
