@@ -11,7 +11,7 @@ import pytest
 
 import polars as pl
 from polars.datatypes import DATETIME_DTYPES, DTYPE_TEMPORAL_UNITS, TEMPORAL_DTYPES
-from polars.exceptions import ComputeError, PanicException
+from polars.exceptions import ComputeError, PolarsPanicError
 from polars.testing import (
     assert_frame_equal,
     assert_series_equal,
@@ -468,9 +468,11 @@ def test_date_range() -> None:
     assert result.dt[2] == datetime(1985, 1, 4, 0, 0)
     assert result.dt[-1] == datetime(2015, 6, 30, 12, 0)
 
-    for tu in DTYPE_TEMPORAL_UNITS:
-        rng = pl.date_range(datetime(2020, 1, 1), date(2020, 1, 2), "2h", time_unit=tu)
-        assert rng.time_unit == tu
+    for time_unit in DTYPE_TEMPORAL_UNITS:
+        rng = pl.date_range(
+            datetime(2020, 1, 1), date(2020, 1, 2), "2h", time_unit=time_unit
+        )
+        assert rng.time_unit == time_unit
         assert rng.shape == (13,)
         assert rng.dt[0] == datetime(2020, 1, 1)
         assert rng.dt[-1] == datetime(2020, 1, 2)
@@ -505,7 +507,7 @@ def test_date_range() -> None:
         datetime(2022, 1, 1), datetime(2022, 1, 1, 0, 1), "987456321ns"
     )
     assert len(result) == 61
-    assert result.dtype.tu == "ns"  # type: ignore[union-attr]
+    assert result.dtype.time_unit == "ns"  # type: ignore[union-attr]
     assert result.dt.second()[-1] == 59
     assert result.cast(pl.Utf8)[-1] == "2022-01-01 00:00:59.247379260"
 
@@ -531,9 +533,9 @@ def test_date_range_precision(time_unit: TimeUnit | None, expected_micros: int)
 
 
 def test_range_invalid_unit() -> None:
-    with pytest.raises(PanicException, match="'D' not supported"):
+    with pytest.raises(PolarsPanicError, match="'D' not supported"):
         pl.date_range(
-            low=datetime(2021, 12, 16), high=datetime(2021, 12, 16, 3), interval="1D"
+            start=datetime(2021, 12, 16), end=datetime(2021, 12, 16, 3), interval="1D"
         )
 
 
@@ -962,8 +964,8 @@ def test_upsample_time_zones(
     df = pl.DataFrame(
         {
             "time": pl.date_range(
-                low=datetime(2021, 12, 16),
-                high=datetime(2021, 12, 16, 3),
+                start=datetime(2021, 12, 16),
+                end=datetime(2021, 12, 16, 3),
                 interval="30m",
             ),
             "groups": ["a", "a", "a", "b", "b", "a", "a"],
@@ -1622,10 +1624,10 @@ def test_datetime_instance_selection() -> None:
             ("ms", pl.Datetime("ms")),
         ],
     )
-    for tu in DTYPE_TEMPORAL_UNITS:
-        res = df.select(pl.col([pl.Datetime(tu)])).dtypes
-        assert res == [pl.Datetime(tu)]
-        assert len(df.filter(pl.col(tu) == test_data[tu][0])) == 1
+    for time_unit in DTYPE_TEMPORAL_UNITS:
+        res = df.select(pl.col([pl.Datetime(time_unit)])).dtypes
+        assert res == [pl.Datetime(time_unit)]
+        assert len(df.filter(pl.col(time_unit) == test_data[time_unit][0])) == 1
 
     assert [] == list(df.select(pl.exclude(DATETIME_DTYPES)))
 
@@ -1807,7 +1809,7 @@ def test_supertype_timezones_4174() -> None:
 
     # test if this runs without error
     date_to_fill = df["dt_London"][0]
-    df.with_columns(df["dt_London"].shift_and_fill(1, date_to_fill))
+    df.with_columns(df["dt_London"].shift_and_fill(date_to_fill, periods=1))
 
 
 @pytest.mark.skip(reason="from_dicts cannot yet infer timezones")
@@ -1832,7 +1834,7 @@ def test_shift_and_fill_group_logicals() -> None:
         schema=["d", "s"],
     )
     assert df.select(
-        pl.col("d").shift_and_fill(-1, pl.col("d").max()).over("s")
+        pl.col("d").shift_and_fill(pl.col("d").max(), periods=-1).over("s")
     ).dtypes == [pl.Date]
 
 
@@ -1911,14 +1913,14 @@ def test_replace_timezone() -> None:
     ],
 )
 @pytest.mark.parametrize("from_tz", ["Asia/Seoul", "-01:00", None])
-@pytest.mark.parametrize("tu", ["ms", "us", "ns"])
+@pytest.mark.parametrize("time_unit", ["ms", "us", "ns"])
 def test_replace_timezone_from_to(
     from_tz: str,
     to_tz: str,
     tzinfo: timezone | ZoneInfo,
-    tu: TimeUnit,
+    time_unit: TimeUnit,
 ) -> None:
-    ts = pl.Series(["2020-01-01"]).str.strptime(pl.Datetime(tu))
+    ts = pl.Series(["2020-01-01"]).str.strptime(pl.Datetime(time_unit))
     result = ts.dt.replace_time_zone(from_tz).dt.replace_time_zone(to_tz).item()
     expected = datetime(2020, 1, 1, 0, 0, tzinfo=tzinfo)
     assert result == expected
@@ -1934,16 +1936,16 @@ def test_strptime_with_tz() -> None:
 
 
 @pytest.mark.parametrize(
-    ("tu", "tz"),
+    ("time_unit", "time_zone"),
     [
         ("us", "Europe/London"),
         ("ms", None),
         ("ns", "+01:00"),
     ],
 )
-def test_strptime_empty(tu: TimeUnit, tz: str | None) -> None:
-    ts = pl.Series([None]).cast(pl.Utf8).str.strptime(pl.Datetime(tu, tz))
-    assert ts.dtype == pl.Datetime(tu, tz)
+def test_strptime_empty(time_unit: TimeUnit, time_zone: str | None) -> None:
+    ts = pl.Series([None]).cast(pl.Utf8).str.strptime(pl.Datetime(time_unit, time_zone))
+    assert ts.dtype == pl.Datetime(time_unit, time_zone)
 
 
 def test_strptime_with_invalid_tz() -> None:
@@ -2208,19 +2210,6 @@ def test_replace_time_zone_from_naive() -> None:
     }
 
 
-@pytest.mark.parametrize("time_zone", ["UTC", "Africa/Abidjan"])
-def test_tz_localize_from_tz_aware(time_zone: str) -> None:
-    tz_aware = (
-        pl.Series(["2018-10-28"])
-        .str.strptime(pl.Datetime)
-        .dt.replace_time_zone(time_zone)
-    )
-    deprecation_msg = "please use `.replace_time_zone` instead"
-    with pytest.warns(DeprecationWarning, match=deprecation_msg):
-        # ignoring as this is being redirected and will be removed anyway
-        tz_aware.dt.tz_localize("America/Maceio")  # type: ignore[attr-defined]
-
-
 def test_unlocalize() -> None:
     tz_naive = pl.Series(["2020-01-01 03:00:00"]).str.strptime(pl.Datetime)
     tz_aware = tz_naive.dt.replace_time_zone("UTC").dt.convert_time_zone(
@@ -2234,7 +2223,7 @@ def test_tz_aware_truncate() -> None:
     test = pl.DataFrame(
         {
             "dt": pl.date_range(
-                low=datetime(2022, 11, 1), high=datetime(2022, 11, 4), interval="12h"
+                start=datetime(2022, 11, 1), end=datetime(2022, 11, 4), interval="12h"
             ).dt.replace_time_zone("America/New_York")
         }
     )
@@ -2265,8 +2254,8 @@ def test_tz_aware_truncate() -> None:
     lf = pl.DataFrame(
         {
             "naive": pl.date_range(
-                low=datetime(2021, 12, 31, 23),
-                high=datetime(2022, 1, 1, 6),
+                start=datetime(2021, 12, 31, 23),
+                end=datetime(2022, 1, 1, 6),
                 interval="1h",
             )
         }
@@ -2332,7 +2321,7 @@ def test_tz_aware_strftime() -> None:
     df = pl.DataFrame(
         {
             "dt": pl.date_range(
-                low=datetime(2022, 11, 1), high=datetime(2022, 11, 4), interval="24h"
+                start=datetime(2022, 11, 1), end=datetime(2022, 11, 4), interval="24h"
             ).dt.replace_time_zone("America/New_York")
         }
     )
