@@ -12,7 +12,7 @@ import polars as pl
 from polars.testing import assert_frame_equal
 
 if TYPE_CHECKING:
-    from polars.internals.type_aliases import ParallelStrategy
+    from polars.type_aliases import ParallelStrategy
 
 
 @pytest.fixture()
@@ -331,6 +331,7 @@ def test_streaming_categorical() -> None:
                 .groupby("name")
                 .agg(pl.col("amount").sum())
                 .collect()
+                .sort("name")
             )
             expected = pl.DataFrame(
                 {"name": ["Bob", "Alice"], "amount": [400, 200]},
