@@ -112,13 +112,20 @@ def test_str_to_uppercase() -> None:
     assert_series_equal(s.str.to_uppercase(), expected)
 
 
+def test_str_case_cyrillic() -> None:
+    vals = ["Biтpyк", "Iвaн"]
+    s = pl.Series(vals)
+    assert s.str.to_lowercase().to_list() == [a.lower() for a in vals]
+    assert s.str.to_uppercase().to_list() == [a.upper() for a in vals]
+
+
 def test_str_parse_int() -> None:
     bin = pl.Series(["110", "101", "010"])
     assert_series_equal(bin.str.parse_int(2), pl.Series([6, 5, 2]).cast(pl.Int32))
 
     hex = pl.Series(["fa1e", "ff00", "cafe", "invalid", None])
     assert_series_equal(
-        hex.str.parse_int(16, False),
+        hex.str.parse_int(16, strict=False),
         pl.Series([64030, 65280, 51966, None, None]).cast(pl.Int32),
         check_exact=True,
     )
@@ -135,7 +142,10 @@ def test_str_parse_int_df() -> None:
         }
     )
     out = df.with_columns(
-        [pl.col("bin").str.parse_int(2, False), pl.col("hex").str.parse_int(16, False)]
+        [
+            pl.col("bin").str.parse_int(2, strict=False),
+            pl.col("hex").str.parse_int(16, strict=False),
+        ]
     )
 
     expected = pl.DataFrame(
