@@ -9,7 +9,7 @@ import numpy as np
 import pytest
 
 import polars as pl
-from polars.testing import assert_frame_equal
+from polars.testing import assert_frame_equal, assert_series_equal
 
 
 def test_sort_dates_multiples() -> None:
@@ -54,10 +54,10 @@ def test_sort_by() -> None:
     out = df.select(pl.col("a").sort_by("b", "c"))
     assert out["a"].to_list() == [3, 1, 2, 5, 4]
 
-    out = df.select(pl.col("a").sort_by(by, descending=[False]))
+    out = df.select(pl.col("a").sort_by(by, descending=False))
     assert out["a"].to_list() == [3, 1, 2, 5, 4]
 
-    out = df.select(pl.col("a").sort_by(by, descending=[True]))
+    out = df.select(pl.col("a").sort_by(by, descending=True))
     assert out["a"].to_list() == [4, 5, 2, 1, 3]
 
     out = df.select(pl.col("a").sort_by(by, descending=[True, False]))
@@ -252,14 +252,17 @@ def test_arg_sort_rank_nans() -> None:
 
 def test_top_k() -> None:
     # expression
-    s = pl.Series([3, 1, 2, 5, 8])
+    s = pl.Series("a", [3, 8, 1, 5, 2])
 
-    assert s.top_k(3).to_list() == [8, 5, 3]
-    assert s.top_k(4, descending=True).to_list() == [1, 2, 3, 5]
+    assert_series_equal(s.top_k(3), pl.Series("a", [8, 5, 3]))
+    assert_series_equal(s.bottom_k(4), pl.Series("a", [1, 2, 3, 5]))
 
     # 5886
-    df = pl.DataFrame({"test": [4, 3, 2, 1]})
-    assert_frame_equal(df.select(pl.col("test").top_k(10)), df)
+    df = pl.DataFrame({"test": [2, 4, 1, 3]})
+    assert_frame_equal(
+        df.select(pl.col("test").top_k(10)),
+        pl.DataFrame({"test": [4, 3, 2, 1]}),
+    )
 
     # dataframe
     df = pl.DataFrame(
@@ -269,15 +272,19 @@ def test_top_k() -> None:
         }
     )
 
-    assert df.top_k(3, by=["a", "b"]).to_dict(False) == {"a": [4, 3, 2], "b": [4, 1, 3]}
+    assert_frame_equal(
+        df.top_k(3, by=["a", "b"]),
+        pl.DataFrame({"a": [4, 3, 2], "b": [4, 1, 3]}),
+    )
 
-    assert df.top_k(
-        3,
-        by=["a", "b"],
-        descending=True,
-    ).to_dict(
-        False
-    ) == {"a": [1, 2, 2], "b": [3, 2, 2]}
+    assert_frame_equal(
+        df.top_k(3, by=["a", "b"], descending=True),
+        pl.DataFrame({"a": [1, 2, 2], "b": [3, 2, 2]}),
+    )
+    assert_frame_equal(
+        df.bottom_k(4, by=["a", "b"], descending=True),
+        pl.DataFrame({"a": [4, 3, 2, 2], "b": [4, 1, 3, 2]}),
+    )
 
 
 def test_sorted_flag_unset_by_arithmetic_4937() -> None:
@@ -554,3 +561,88 @@ def test_limit_larger_than_sort() -> None:
     assert pl.LazyFrame({"a": [1]}).sort("a").limit(30).collect().to_dict(False) == {
         "a": [1]
     }
+
+
+def test_sort_by_struct() -> None:
+    df = pl.Series([{"a": 300}, {"a": 20}, {"a": 55}]).to_frame("st").with_row_count()
+    assert df.sort("st").to_dict(False) == {
+        "row_nr": [1, 2, 0],
+        "st": [{"a": 20}, {"a": 55}, {"a": 300}],
+    }
+
+
+def test_sort_descending() -> None:
+    df = pl.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]})
+    result = df.sort(["a", "b"], descending=True)
+    expected = pl.DataFrame({"a": [3, 2, 1], "b": [6, 5, 4]})
+    assert_frame_equal(result, expected)
+    result = df.sort(["a", "b"], descending=[True, True])
+    assert_frame_equal(result, expected)
+    with pytest.raises(
+        ValueError,
+        match=r"the length of `descending` \(1\) does not match the length of `by` \(2\)",
+    ):
+        df.sort(["a", "b"], descending=[True])
+
+
+def test_top_k_descending() -> None:
+    df = pl.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]})
+    result = df.top_k(1, by=["a", "b"], descending=True)
+    expected = pl.DataFrame({"a": [1], "b": [4]})
+    assert_frame_equal(result, expected)
+    result = df.top_k(1, by=["a", "b"], descending=[True, True])
+    assert_frame_equal(result, expected)
+    with pytest.raises(
+        ValueError,
+        match=r"the length of `descending` \(1\) does not match the length of `by` \(2\)",
+    ):
+        df.top_k(1, by=["a", "b"], descending=[True])
+
+
+def test_sort_by_descending() -> None:
+    df = pl.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]})
+    result = df.select(pl.col("a").sort_by(["a", "b"], descending=True))
+    expected = pl.DataFrame({"a": [3, 2, 1]})
+    assert_frame_equal(result, expected)
+    result = df.select(pl.col("a").sort_by(["a", "b"], descending=[True, True]))
+    assert_frame_equal(result, expected)
+    with pytest.raises(
+        ValueError,
+        match=r"the length of `descending` \(1\) does not match the length of `by` \(2\)",
+    ):
+        df.select(pl.col("a").sort_by(["a", "b"], descending=[True]))
+
+
+def test_arg_sort_by_descending() -> None:
+    df = pl.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]})
+    result = df.select(pl.arg_sort_by(["a", "b"], descending=True))
+    expected = pl.DataFrame({"a": [2, 1, 0]}).select(pl.col("a").cast(pl.UInt32))
+    assert_frame_equal(result, expected)
+    result = df.select(pl.arg_sort_by(["a", "b"], descending=[True, True]))
+    assert_frame_equal(result, expected)
+    with pytest.raises(
+        ValueError,
+        match=r"the length of `descending` \(1\) does not match the length of `exprs` \(2\)",
+    ):
+        df.select(pl.arg_sort_by(["a", "b"], descending=[True]))
+
+
+def test_arg_sort_struct() -> None:
+    df = pl.DataFrame(
+        {
+            "a": [100, 300, 100, 200, 200, 100, 300, 200, 400, 400],
+            "b": [5, 5, 6, 7, 8, 1, 1, 2, 2, 3],
+        }
+    )
+    assert df.select(pl.struct("a", "b").arg_sort()).to_series().to_list() == [
+        5,
+        0,
+        2,
+        7,
+        3,
+        4,
+        6,
+        1,
+        8,
+        9,
+    ]
