@@ -9,6 +9,7 @@ import numpy as np
 import pandas as pd
 import pyarrow as pa
 import pytest
+from numpy.testing import assert_array_equal
 
 import polars as pl
 from polars.testing import assert_frame_equal, assert_series_equal
@@ -71,8 +72,7 @@ def test_to_numpy() -> None:
     ) -> None:
         pl_series_to_numpy_array = np.array(pl.Series(name, values, pl_dtype))
         numpy_array = np.array(values, dtype=np_dtype)
-        assert pl_series_to_numpy_array.dtype == numpy_array.dtype
-        assert np.all(pl_series_to_numpy_array == numpy_array) == np.bool_(True)
+        assert_array_equal(pl_series_to_numpy_array, numpy_array)
 
     test_series_to_numpy("int8", [1, 3, 2], pl.Int8, np.int8)
     test_series_to_numpy("int16", [1, 3, 2], pl.Int16, np.int16)
@@ -488,12 +488,14 @@ def test_cat_to_pandas() -> None:
     df = df.with_columns(pl.all().cast(pl.Categorical))
     pd_out = df.to_pandas()
     assert "category" in str(pd_out["a"].dtype)
-
     try:
         pd_pa_out = df.to_pandas(use_pyarrow_extension_array=True)
-        assert pd_pa_out["a"].dtype.type == pa.DictionaryType
+        assert pd_pa_out["a"].dtype.type in (
+            pd.core.dtypes.dtypes.CategoricalDtypeType,
+            pa.DictionaryType,
+        )
     except ModuleNotFoundError:
-        # Skip test if Pandas 1.5.x is not installed.
+        # Skip test if suitable pandas version not installed.
         pass
 
 
@@ -604,7 +606,7 @@ def test_from_empty_arrow() -> None:
     assert df.dtypes == [pl.Float64, pl.Float64]
 
     # 2705
-    df1 = pd.DataFrame(columns=["b"], dtype=float)
+    df1 = pd.DataFrame(columns=["b"], dtype=float, index=pd.Index([]))
     tbl = pa.Table.from_pandas(df1)
     out = cast(pl.DataFrame, pl.from_arrow(tbl))
     assert out.columns == ["b", "__index_level_0__"]
@@ -669,7 +671,9 @@ def test_cat_int_types_3500() -> None:
 
         for t in [int_dict_type, uint_dict_type]:
             s = cast(pl.Series, pl.from_arrow(pyarrow_array.cast(t)))
-            assert_series_equal(s, pl.Series(["a", "a", "b"]).cast(pl.Categorical))
+            assert_series_equal(
+                s, pl.Series(["a", "a", "b"]).cast(pl.Categorical), check_names=False
+            )
 
 
 def test_from_pyarrow_chunked_array() -> None:
@@ -695,9 +699,7 @@ def test_arrow_list_null_5697() -> None:
     df = pl.from_arrow(pa_table)
     pa_table = df.to_arrow()
     # again to polars to test the schema
-    assert pl.from_arrow(pa_table).schema == {  # type: ignore[union-attr]
-        "mycol": pl.List(pl.Null)
-    }
+    assert pl.from_arrow(pa_table).schema == {"mycol": pl.List(pl.Null)}  # type: ignore[union-attr]
 
 
 def test_from_pandas_null_struct_6412() -> None:
